==> querydsl-parser-0.1-sources.jar: foundation/jpa/querydsl/StateExpression2.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateExpression2 extends StackState<com.querydsl.core.types.Expression, State> {

// NoStack:
// Stack:
    public StateExpression2(foundation.jpa.querydsl.QueryFactory factory, com.querydsl.core.types.Expression node, State prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitAnd(symbol);
    }


// Shift:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) {
        return new StateEqual2(getFactory(), symbol, this);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) {
        return new StateIn2(getFactory(), symbol, this);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) {
        return new StateTilda2(getFactory(), symbol, this);
    }


// Accept:
    @Override
    public List<Object> stack() {
        State stack1 = this.getPrev();
        return Arrays.asList(this.getNode());
    }

}

==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateExpression2.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateExpression2 extends StackState<com.querydsl.core.types.Expression, State> {

// NoStack:
// Stack:
    public StateExpression2(foundation.jpa.querydsl.QueryFactory factory, com.querydsl.core.types.Expression node, State prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitRelationalBooleanExpression(getFactory().is(this.getNode())).visitAnd(symbol);
    }


// Shift:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) {
        return new StateEqual2(getFactory(), symbol, this);
    }

    @Override
    public State visitIs(foundation.rpg.common.symbols.Is symbol) {
        return new StateIs2(getFactory(), symbol, this);
    }

    @Override
    public State visitNot(foundation.rpg.common.symbols.Not symbol) {
        return new StateNot8(getFactory(), symbol, this);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) {
        return new StateIn2(getFactory(), symbol, this);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) {
        return new StateTilda2(getFactory(), symbol, this);
    }


// Accept:
    @Override
    public List<Object> stack() {
        State stack1 = this.getPrev();
        return Arrays.asList(this.getNode());
    }

}
